#include <Adafruit_NeoPixel.h>

#define PIN 3
#define NUM_LEDS 57

Adafruit_NeoPixel strip = Adafruit_NeoPixel(NUM_LEDS, PIN, NEO_GRB + NEO_KHZ800);

int color = strip.Color(205, 185, 255);
int null = strip.Color(0, 0, 0);
int ringSizes[] = {20, 16, 12, 8, 1}; // Number of pixels in each ring
float delayTime = 18;

void setup() {
  strip.begin();
  strip.setBrightness(10);
}

void loop() {
  for (int ring=4; ring>=0; ring--) {
    // Calculate start and end pixel indices for current ring
    int startPixel = 0;
    for (int i=0; i<ring; i++) {
      startPixel += ringSizes[i];
    }

    // Fade out previous rings
    int endPixel = startPixel + ringSizes[ring] - 1;
    for (int j=ring+1; j<=min(4,ring+3); j++) {
      int prevStartPixel = 0;
      for (int i=0; i<j; i++) {
        prevStartPixel += ringSizes[i];
      }
      
      int prevEndPixel = prevStartPixel + ringSizes[j] - 1;
      for (int i=prevStartPixel; i<= prevEndPixel; i++) {
        int prevPixelColor = strip.getPixelColor(i);
        int brightness = (255 - (j - ring) * 75) / 255;
        strip.setPixelColor(i, brightness, brightness, brightness);
      }
    }
    
    // Set current ring to a color
    for (int i=startPixel; i<endPixel; i++) {
      strip.setPixelColor(i, color);
    }
    
    strip.show();
    delay(delayTime);

    // Turn off current ring
    for (int i = startPixel; i <= endPixel; i++) {
      strip.setPixelColor(i, null);
    }
    
    // Fade out fill-in for trailing ring
    if (ring == 0) {
      for (int b=255; b>=0; b--) {
        for (int i = startPixel; i <= endPixel; i++) {
          strip.setPixelColor(i, b, b, b);
        }
        strip.show();
      }
    }
    
    // Turn off previous rings
    for (int j=ring+1; j <=min(4,ring+3); j++) {
      int prevStartPixel = 0;
      for (int i = 0; i < j; i++) {
        prevStartPixel += ringSizes[i];
      }

      int prevEndPixel = prevStartPixel + ringSizes[j] - 1;
      for (int i=prevStartPixel; i<=prevEndPixel; i++) {
        strip.setPixelColor(i, null);
      }
    }
  }
}